<?php
session_start(); // Start or continue the session to access $_SESSION data

require 'db_config.php'; // Ensure this file sets up $conn properly
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Our Valuation</title>
    <link rel="stylesheet" href="css/style.css">
</head>
<body>
    <?php include 'header.php'; ?>

    <div class="container">
        <?php
        // Check request method
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            // Retrieve VRM and mileage from session or POST
            // Prefer session first, then fall back to POST if needed
            $vehicle_registration = $_SESSION['vehicle_registration'] ?? $_POST['vehicle_registration'] ?? '';
            $mileage = $_SESSION['mileage'] ?? $_POST['mileage'] ?? 0;

            // Collect user details from POST
            $first_name  = htmlspecialchars($_POST['first_name'] ?? '');
            $last_name   = htmlspecialchars($_POST['last_name'] ?? '');
            $email       = htmlspecialchars($_POST['email'] ?? '');
            $phone       = htmlspecialchars($_POST['phone'] ?? '');

            // Debug checks (optional, for troubleshooting)
            // echo "<p>VRM: $vehicle_registration</p>";
            // echo "<p>Mileage: $mileage</p>";

            // If VRM is missing, stop here
            if (empty($vehicle_registration)) {
                echo "<h2>Error</h2>";
                echo "<p>No vehicle registration found. Please go back and try again.</p>";
                exit;
            }

            // Build API URL
            $api_key = "5ddf07e0ff071e9d683a39f2e8444353";
            $api_url = "https://api.checkcardetails.co.uk/vehicledata/vehiclevaluation";
            $query_params = [
                'apikey' => $api_key,
                'vrm' => $vehicle_registration,
                'mileage' => $mileage,
            ];
            $final_url = $api_url . '?' . http_build_query($query_params);

            // Debug check (optional)
            // echo "<p>Final API URL: $final_url</p>";

            // Fetch response from API (remove the '@' to show warnings if any)
            $response = file_get_contents($final_url);

            if ($response === false) {
                // If file_get_contents failed, give a clear error
                echo "<h2>Error</h2>";
                echo "<p>Could not fetch any data from the API (possible connection issue or URL fopen disabled).</p>";
                exit;
            }

            // Decode JSON
            $data = json_decode($response, true);

            // Debug check (optional)
            // echo "<pre>"; print_r($data); echo "</pre>";

            // Check if we got the ValuationList back
            if (isset($data['ValuationList'])) {
                // Extract data
                $trade_average     = $data['ValuationList']['TradeAverage']     ?? 0.0;
                $trade_poor        = $data['ValuationList']['TradePoor']        ?? 0.0;
                $trade_retail      = $data['ValuationList']['TradeRetail']      ?? 0.0;
                $dealer_forecourt  = $data['ValuationList']['DealerForecourt']  ?? 0.0;
                $vehicle_description = $data['VehicleDescription']              ?? '';

                // Insert into DB
                $stmt = $conn->prepare("
                    INSERT INTO vehicle_info 
                    (
                        first_name, 
                        last_name, 
                        email, 
                        phone_number, 
                        vehicle_registration, 
                        mileage, 
                        trade_average, 
                        trade_poor, 
                        trade_retail, 
                        dealer_forecourt, 
                        vehicle_description
                    ) 
                    VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                ");

                if (!$stmt) {
                    // Statement preparation failed
                    echo "<h2>Error</h2>";
                    echo "<p>DB error (prepare): " . $conn->error . "</p>";
                    exit;
                }

                $stmt->bind_param(
                    "sssssidddds",
                    $first_name,
                    $last_name,
                    $email,
                    $phone,
                    $vehicle_registration,
                    $mileage,
                    $trade_average,
                    $trade_poor,
                    $trade_retail,
                    $dealer_forecourt,
                    $vehicle_description
                );

                if ($stmt->execute()) {
                    echo "<h2>Our Valuation</h2>";
                    echo "<p>£" . number_format($trade_poor, 2) . "</p>";
                } else {
                    echo "<h2>Error</h2>";
                    echo "<p>Unable to save your details. Please try again later.</p>";
                }
                $stmt->close();
            } else {
                // No ValuationList => error from API or invalid VRM
                echo "<h2>Error</h2>";
                echo "<p>Unable to fetch the valuation. Please check the VRM or try again later.</p>";
            }
        } else {
            // If someone tries to access save_and_fetch.php directly without POST
            echo "<h2>Error</h2>";
            echo "<p>Unauthorized access. Please start from the homepage.</p>";
        }
        ?>
    </div>

    <?php include 'footer.php'; ?>
</body>
</html>
